﻿using UnityEngine;

public class PlayerScript : MonoBehaviour 
{
	
	enum paddleDirection
	{
		left,
		right,
		clear
	};
	
	public float movementSpeed = 20.0f;
	
	private paddleDirection lockedDirection;
	private paddleDirection currentMovement;
	private bool paddleSelected = false;
	
	
	void Update()
	{
		if (Input.touchCount > 0)
		{
			if (Input.touchCount > 0 && Input.GetTouch(0).phase == TouchPhase.Began) 
			{
				var touch = Input.GetTouch(0);
				var ray = Camera.main.ScreenPointToRay (touch.position);
				if (Physics.Raycast(ray)) 
				{
					print("Paddle selected");
					paddleSelected = true;
				}
			}
			if (Input.touchCount > 0 && Input.GetTouch(0).phase == TouchPhase.Moved) 
			{
				if (paddleSelected) {

					Ray ray = Camera.main.ScreenPointToRay(Input.GetTouch(0).position);
					Plane plane = new Plane(Vector3.up, transform.position);
					float distance = 0; // this will return the distance from the camera
					if (plane.Raycast(ray, out distance)){ // if plane hit...
						Vector3 pos = ray.GetPoint(distance); // get the point
						transform.position = new Vector3 (pos.x , transform.position.y, transform.position.z);
					}
				} 

			}
			if (Input.touchCount > 0 && Input.GetTouch(0).phase == TouchPhase.Ended) 
			{
				paddleSelected = false;
			}
		}
		if (Input.GetKey(KeyCode.LeftArrow) && lockedDirection != paddleDirection.left)
		{
			transform.position = new Vector3 (transform.position.x - Time.deltaTime * movementSpeed, transform.position.y, transform.position.z);
			currentMovement = paddleDirection.left;
			unlockPaddleDirection(paddleDirection.right);
		}
		else if (Input.GetKey(KeyCode.RightArrow) && lockedDirection != paddleDirection.right)
		{
			transform.position = new Vector3 (transform.position.x + (Time.deltaTime * movementSpeed), transform.position.y, transform.position.z);
			currentMovement = paddleDirection.right;
			unlockPaddleDirection(paddleDirection.left);
		}
	}
	
	void OnTriggerEnter()
	{
		lockPaddleDirection(currentMovement);
	}
	
	private void lockPaddleDirection(paddleDirection direction)
	{
		lockedDirection = direction;
	}
	
	private void unlockPaddleDirection(paddleDirection direction)
	{
		lockedDirection = paddleDirection.clear;
	}
	
}

